summaryrefslogtreecommitdiffstats
path: root/chrome/common/render_messages.h
diff options
context:
space:
mode:
authorabarth@chromium.org <abarth@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-23 18:11:10 +0000
committerabarth@chromium.org <abarth@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-23 18:11:10 +0000
commitcfd7332188b64787a9cb2b110957c0eb60b806a8 (patch)
treebd5072b446490dc3266dff44a627416f54404eb8 /chrome/common/render_messages.h
parentd62c805ec92a9e00bfd97fc5a4d35103a8e89380 (diff)
downloadchromium_src-cfd7332188b64787a9cb2b110957c0eb60b806a8.zip
chromium_src-cfd7332188b64787a9cb2b110957c0eb60b806a8.tar.gz
chromium_src-cfd7332188b64787a9cb2b110957c0eb60b806a8.tar.bz2
Rename |policy_url| to |first_party_for_cookies|. This now matches the WebKit name for this piece of data.
R=jackson BUG=None TEST=No behavior change Review URL: http://codereview.chromium.org/115743 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@16843 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common/render_messages.h')
-rw-r--r--chrome/common/render_messages.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/chrome/common/render_messages.h b/chrome/common/render_messages.h
index 5128dfd..7bcfa79 100644
--- a/chrome/common/render_messages.h
+++ b/chrome/common/render_messages.h
@@ -229,12 +229,12 @@ struct ViewHostMsg_Resource_Request {
// The requested URL.
GURL url;
- // The URL of the document in the top-level window, which may be checked by
- // the third-party cookie blocking policy. Leaving it empty may lead to
- // undesired cookie blocking. Third-party cookie blocking can be bypassed by
- // setting policy_url = url, but this should ideally only be done if there
- // really is no way to determine the correct value.
- GURL policy_url;
+ // Usually the URL of the document in the top-level window, which may be
+ // checked by the third-party cookie blocking policy. Leaving it empty may
+ // lead to undesired cookie blocking. Third-party cookie blocking can be
+ // bypassed by setting first_party_for_cookies = url, but this should ideally
+ // only be done if there really is no way to determine the correct value.
+ GURL first_party_for_cookies;
// The referrer to use (may be empty).
GURL referrer;
@@ -1178,7 +1178,7 @@ struct ParamTraits<ViewHostMsg_Resource_Request> {
static void Write(Message* m, const param_type& p) {
WriteParam(m, p.method);
WriteParam(m, p.url);
- WriteParam(m, p.policy_url);
+ WriteParam(m, p.first_party_for_cookies);
WriteParam(m, p.referrer);
WriteParam(m, p.frame_origin);
WriteParam(m, p.main_frame_origin);
@@ -1194,7 +1194,7 @@ struct ParamTraits<ViewHostMsg_Resource_Request> {
return
ReadParam(m, iter, &r->method) &&
ReadParam(m, iter, &r->url) &&
- ReadParam(m, iter, &r->policy_url) &&
+ ReadParam(m, iter, &r->first_party_for_cookies) &&
ReadParam(m, iter, &r->referrer) &&
ReadParam(m, iter, &r->frame_origin) &&
ReadParam(m, iter, &r->main_frame_origin) &&